kedro.framework.cli.utils.KedroCliError — Kedro 0.17.6 documentation

# kedro.framework.cli.utils.KedroCliError

class `kedro.framework.cli.utils.` `KedroCliError`(message)

  Exceptions generated from the Kedro CLI.

  Users should pass an appropriate message at the constructor.

  `VERBOSE_ERROR` = False
  `args`
  `exit_code` = 1
  `format_message`()
  `show`(file=None)
  `with_traceback`()

    Exception.with_traceback(tb) – set self.__traceback__ to tb and return self.